@@ -2,7 +2,7 @@ package HTTP::AcceptCharset;
 
 # ABSTRACT: Parse the HTTP header 'Accept-Charset'
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moo;
 use List::Util qw(first);
@@ -13,12 +13,17 @@ has values => ( is => 'ro', lazy => 1, default => \&_parse_string );
 sub match {
     my ($self, @values_to_check) = @_;
 
+    @values_to_check =
+        map{ lc $_ }
+        grep{ defined $_ && length $_ }
+        @values_to_check;
+
     return '' if !@values_to_check;
-    return '' if !defined $values_to_check[0];
 
     my @charsets = @{ $self->values || [] };
     return $values_to_check[0] if !@charsets;
 
+
     CHARSET:
     for my $charset ( @charsets ) {
         return $values_to_check[0] if $charset eq '*';
@@ -71,7 +76,7 @@ HTTP::AcceptCharset - Parse the HTTP header 'Accept-Charset'
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
